import { __ΩAutoIncrement as __ΩAutoIncrement } from '@deepkit/type';
import { __ΩPrimaryKey as __ΩPrimaryKey } from '@deepkit/type';
import { __ΩPostgres as __ΩPostgres } from '@deepkit/type';
import { __ΩEntity as __ΩEntity } from '@deepkit/type';
import { __ΩUnique as __ΩUnique } from '@deepkit/type';
import { __ΩReference as __ΩReference } from '@deepkit/type';
import { expect, test } from '@jest/globals';
import { schemaMigrationRoundTrip } from '@deepkit/sql';
import { ReflectionClass, typeOf } from '@deepkit/type';
import { PostgresDatabaseAdapter } from '../src/postgres-adapter';
import { DatabaseEntityRegistry } from '@deepkit/orm';
test('custom type', async () => {
    class post {
        constructor() {
            this.id = 0;
            this.slug = '';
            this.content = '';
        }
    }
    post.__type = [() => __ΩAutoIncrement, () => __ΩPrimaryKey, 'id', function () { return 0; }, () => __ΩPostgres, "VARCHAR(255)", 'type', 'slug', function () { return ''; }, 'content', function () { return ''; }, 'P\'n!n"K3#>$P&P.&4\'Mo%"K3(>)&3*>+5'];
    const reflection = ReflectionClass.from(post);
    reflection.getProperty('slug');
    const adapter = new PostgresDatabaseAdapter({ host: '127.0.0.1', database: 'postgres', user: 'postgres' });
    const [postTable] = adapter.platform.createTables(DatabaseEntityRegistry.from([post]));
    expect(postTable.getColumn('slug').type).toBe('varchar');
    expect(postTable.getColumn('slug').size).toBe(255);
    expect(postTable.getColumn('content').type).toBe('text');
    await schemaMigrationRoundTrip([post], adapter);
});
test('default expression', async () => {
    class post {
        constructor() {
            this.id = 0;
            this.str = '';
            this.no = 3;
            this.json = {};
            this.created = new Date;
        }
    }
    post.__type = [() => __ΩAutoIncrement, () => __ΩPrimaryKey, 'id', function () { return 0; }, () => __ΩPostgres, "VARCHAR(255)", 'type', "abc", 'default', 'str', function () { return ''; }, () => __ΩPostgres, 34.5, 'no', function () { return 3; }, () => __ΩPostgres, "jsonb", 'json', function () { return {}; }, () => __ΩPostgres, "now()", 'defaultExpr', 'created', function () { return new Date; }, 'opt', 'P\'n!n"K3#>$P&P.&4\'.(4)Mo%"K3*>+P\'P.-4)Mo,"K3.>/P"P.14\'PM4)Mo0"K32>3PTP.546Mo4"K37>8)3985'];
    const adapter = new PostgresDatabaseAdapter({ host: '127.0.0.1', database: 'postgres', user: 'postgres' });
    const [postTable] = adapter.platform.createTables(DatabaseEntityRegistry.from([post]));
    expect(postTable.getColumn('str').defaultValue).toBe('abc');
    expect(postTable.getColumn('no').defaultValue).toBe(34.5);
    expect(postTable.getColumn('created').defaultExpression).toBe('now()');
    await schemaMigrationRoundTrip([post], adapter);
});
test('numbers', async () => {
    class post {
        constructor() {
            this.id = 0;
            this.int8 = 0;
            this.uint8 = 0;
            this.int16 = 0;
            this.uint16 = 0;
            this.int32 = 0;
            this.uint32 = 0;
            this.float32 = 0;
            this.default = 0;
        }
    }
    post.__type = [() => __ΩAutoIncrement, () => __ΩPrimaryKey, 'id', function () { return 0; }, 'int8', function () { return 0; }, 'uint8', function () { return 0; }, 'int16', function () { return 0; }, 'uint16', function () { return 0; }, 'int32', function () { return 0; }, 'uint32', function () { return 0; }, 'float32', function () { return 0; }, 'default', function () { return 0; }, 'P(!n!n"K3#>$("3%>&(%3\'>((#3)>*(&3+>,($3->.(\'3/>0()31>2\'33>45'];
    const adapter = new PostgresDatabaseAdapter({ host: '127.0.0.1', database: 'postgres', user: 'postgres' });
    const [postTable] = adapter.platform.createTables(DatabaseEntityRegistry.from([post]));
    const DDL = await schemaMigrationRoundTrip([post], adapter);
    expect(DDL).toContain(`CREATE TABLE "post" (
    "id" SERIAL,
    "int8" smallint NOT NULL DEFAULT 0,
    "uint8" smallint NOT NULL DEFAULT 0,
    "int16" smallint NOT NULL DEFAULT 0,
    "uint16" smallint NOT NULL DEFAULT 0,
    "int32" integer NOT NULL DEFAULT 0,
    "uint32" integer NOT NULL DEFAULT 0,
    "float32" real NOT NULL DEFAULT 0,
    "default" double precision NOT NULL DEFAULT 0,
    PRIMARY KEY ("id")
)`);
});
const __ΩUser = [() => __ΩEntity, "user", 'name', () => __ΩAutoIncrement, () => __ΩPrimaryKey, 'id', () => __ΩUnique, 'username', 'created', 'deleted', 'logins', 'PP."4#Mo!"P\'n$n%K4&P&n\'K4(T4))4*\'4+M'];
const __ΩPost = [() => __ΩEntity, "post", 'name', () => __ΩAutoIncrement, () => __ΩPrimaryKey, 'id', () => __ΩUser, () => __ΩReference, 'user', 'created', () => __ΩUnique, 'slag', 'title', 'content', 'PP."4#Mo!"P\'n$n%K4&Pn\'n(K4)T4*P&n+K4,&4-&4.M'];
test('postgres', async () => {
    await schemaMigrationRoundTrip([typeOf([], [() => __ΩUser, 'n!']), typeOf([], [() => __ΩPost, 'n!'])], new PostgresDatabaseAdapter({ host: 'localhost', database: 'postgres', user: 'postgres' }));
});
//# sourceMappingURL=migration.spec.js.map